@@ -215,18 +215,36 @@ class BatchDownloadUseCase:
             # Use fetch_all_problems_with_status to get complete list of solved problems
             problems = self.client.fetch_all_problems_with_status(status_filter="ac")
             self.logger.info(f"Found {len(problems)} solved problems")
-
-            # Apply limit if specified
-            if options.limit and options.limit < len(problems):
-                self.logger.info(f"Limiting to {options.limit} problems as requested")
-                problems = problems[: options.limit]
         except Exception as e:
             self.logger.error(f"Failed to fetch solved problems for user '{options.username}': {e}")
             raise
 
-        # Apply filters
+        # Apply filters (difficulty, topics)
         problems = self._apply_filters(problems, options)
-        self.logger.info(f"After filtering: {len(problems)} problems to download")
+        self.logger.info(f"After filtering: {len(problems)} problems")
+
+        # For SKIP mode, filter out already-downloaded problems BEFORE applying limit
+        # This ensures --limit applies to NEW problems only
+        if options.update_mode == UpdateMode.SKIP:
+            original_count = len(problems)
+            problems = [p for p in problems if not self.repository.exists(p.id, p.platform)]
+            already_downloaded = original_count - len(problems)
+            if already_downloaded > 0:
+                self.logger.info(
+                    f"Found {already_downloaded} already-downloaded problems, "
+                    f"will skip them ({len(problems)} new problems available)"
+                )
+
+        # Apply limit AFTER filtering out existing problems
+        # This ensures --limit X downloads X NEW problems, not X total problems
+        if options.limit and options.limit < len(problems):
+            self.logger.info(
+                f"Limiting to {options.limit} new problems to download "
+                f"(out of {len(problems)} available)"
+            )
+            problems = problems[: options.limit]
+
+        self.logger.info(f"Will download {len(problems)} problems")
 
         # Notify observers that batch is starting
         self._notify_start(len(problems))
@@ -318,21 +336,55 @@ class BatchDownloadUseCase:
         """
         problem_exists = self.repository.exists(problem.id, problem.platform)
 
-        # Handle SKIP mode
+        # Handle SKIP mode - should not reach here if already exists (pre-filtered)
         if options.update_mode == UpdateMode.SKIP and problem_exists:
             self.logger.debug(f"Skipping problem '{problem.id}' (already exists, mode=SKIP)")
             stats.skipped += 1
             self._notify_skip(problem, "Already exists")
             return
 
-        # Handle UPDATE mode
+        # Handle UPDATE mode - check if submission is newer
         if options.update_mode == UpdateMode.UPDATE and problem_exists:
-            # For UPDATE mode, we would need to check if submission is newer
-            # For now, we'll skip if it exists (can be enhanced later)
-            self.logger.debug(f"Skipping problem '{problem.id}' (already exists, mode=UPDATE)")
-            stats.skipped += 1
-            self._notify_skip(problem, "Already exists (UPDATE mode)")
-            return
+            # Get stored submission timestamp
+            stored_timestamp = self.repository.get_submission_timestamp(
+                problem.id, problem.platform
+            )
+
+            if stored_timestamp is not None:
+                # Fetch latest submission from platform to compare timestamps
+                try:
+                    latest_submission = self.client.fetch_submission(problem.id, options.username)
+
+                    # Compare timestamps - skip if stored submission is same or newer
+                    if latest_submission.timestamp <= stored_timestamp:
+                        self.logger.debug(
+                            f"Skipping problem '{problem.id}' "
+                            f"(stored submission is up-to-date, mode=UPDATE)"
+                        )
+                        stats.skipped += 1
+                        self._notify_skip(problem, "Submission is up-to-date")
+                        return
+                    else:
+                        self.logger.info(
+                            f"Newer submission found for '{problem.id}' "
+                            f"(platform: {latest_submission.timestamp}, "
+                            f"stored: {stored_timestamp})"
+                        )
+                        # Continue to download the newer submission
+                except Exception as e:
+                    self.logger.warning(
+                        f"Failed to fetch submission for comparison on '{problem.id}': {e}. "
+                        "Skipping update."
+                    )
+                    stats.skipped += 1
+                    self._notify_skip(problem, "Failed to check for newer submission")
+                    return
+            else:
+                # Problem exists but has no submission stored - re-download to add submission
+                self.logger.info(
+                    f"Problem '{problem.id}' exists but has no submission, will update"
+                )
+                # Continue to download
 
         # Download problem (FORCE mode or problem doesn't exist)
         self.logger.info(f"Downloading problem '{problem.id}'")
@@ -348,6 +400,9 @@ class BatchDownloadUseCase:
             )
             submission = self.client.fetch_submission(problem.id, options.username)
             self.logger.debug(f"Successfully fetched submission for '{problem.id}'")
+            # Add extra delay after submission fetch to avoid rate limiting
+            # LeetCode's submission API is more aggressive with rate limits
+            time.sleep(1.0)
         except Exception as e:
             self.logger.warning(
                 f"Failed to fetch submission for problem '{problem.id}': {e}. "
