@@ -148,9 +148,13 @@ class LeetCodeClient(PlatformClient):
         Uses the LeetCode GraphQL API to fetch the list of problems
         that a user has solved (accepted submissions).
 
+        NOTE: LeetCode's recentAcSubmissionList API has limitations and may not
+        return all solved problems. For a complete list, use fetch_all_problems_with_status()
+        which fetches all problems with their solve status.
+
         Args:
             username: The LeetCode username
-            limit: Optional maximum number of problems to fetch (default: None = all, max: 1000)
+            limit: Optional maximum number of problems to fetch (default: None = all available)
 
         Returns:
             List of Problem entities for all solved problems (up to limit)
@@ -172,8 +176,9 @@ class LeetCodeClient(PlatformClient):
             + (f" (limit: {limit})" if limit else "")
         )
 
-        # Determine the actual limit to use (default to 1000 if not specified)
-        fetch_limit = min(limit, 1000) if limit else 1000
+        # LeetCode's recentAcSubmissionList is limited, so we fetch as much as possible
+        # The API typically returns up to 20-100 recent submissions
+        fetch_limit = limit if limit else 1000
 
         # GraphQL query for fetching user's solved problems
         query = """
@@ -214,14 +219,33 @@ class LeetCodeClient(PlatformClient):
             # Get list of solved problems
             submissions = data.get("data", {}).get("recentAcSubmissionList", [])
 
+            # Log warning if we got fewer problems than expected
+            total_solved = 0
+            submit_stats = data.get("data", {}).get("matchedUser", {}).get("submitStats", {})
+            if submit_stats:
+                ac_submissions = submit_stats.get("acSubmissionNum", [])
+                total_solved = sum(item.get("count", 0) for item in ac_submissions)
+
+                if len(submissions) < total_solved:
+                    self.logger.warning(
+                        f"LeetCode API returned {len(submissions)} problems but user has {total_solved} "
+                        f"total solved. The recentAcSubmissionList API is limited. "
+                        f"Use fetch_all_problems_with_status() to get all problems with their status."
+                    )
+
             # Apply user-specified limit if provided
             if limit and limit < len(submissions):
                 submissions = submissions[:limit]
 
+            self.logger.info(f"Fetched {len(submissions)} submission records from API")
+
             # Fetch full details for each problem
             problems = []
-            for submission in submissions:
+            for i, submission in enumerate(submissions):
                 try:
+                    self.logger.debug(
+                        f"Fetching problem {i+1}/{len(submissions)}: {submission['titleSlug']}"
+                    )
                     problem = self.fetch_problem(submission["titleSlug"])
                     problems.append(problem)
                 except Exception as e:
@@ -235,6 +259,130 @@ class LeetCodeClient(PlatformClient):
             self.logger.error(f"Failed to fetch solved problems for {username}: {e}")
             raise
 
+    def fetch_all_problems_with_status(self, status_filter: str = None) -> List[Problem]:
+        """Fetch all LeetCode problems with their solve status.
+
+        Uses the LeetCode problemsetQuestionList GraphQL API to fetch all problems
+        along with their status (solved/attempted/not started). This is more comprehensive
+        than fetch_solved_problems() but slower as it fetches all problems.
+
+        Args:
+            status_filter: Optional filter for problem status:
+                          - "ac" or "SOLVED": Only solved problems
+                          - "notac" or "ATTEMPTED": Only attempted but not solved
+                          - None: All problems with their status
+
+        Returns:
+            List of Problem entities with their solve status
+
+        Raises:
+            NetworkException: If the network request fails
+            AuthenticationException: If authentication is required but not provided
+
+        Example:
+            >>> # Get all problems with status
+            >>> all_problems = client.fetch_all_problems_with_status()
+            >>> solved = [p for p in all_problems if hasattr(p, 'status') and p.status == 'ac']
+            >>> print(f"Solved {len(solved)} out of {len(all_problems)} problems")
+
+            >>> # Get only solved problems
+            >>> solved_problems = client.fetch_all_problems_with_status(status_filter="ac")
+            >>> print(f"Solved {len(solved_problems)} problems")
+        """
+        self.logger.info(
+            f"Fetching all problems with status"
+            + (f" (filter: {status_filter})" if status_filter else "")
+        )
+
+        # GraphQL query for fetching all problems with status
+        query = """
+        query problemsetQuestionList($categorySlug: String, $limit: Int, $skip: Int, $filters: QuestionListFilterInput) {
+            problemsetQuestionList: questionList(
+                categorySlug: $categorySlug
+                limit: $limit
+                skip: $skip
+                filters: $filters
+            ) {
+                total: totalNum
+                questions: data {
+                    acRate
+                    difficulty
+                    frontendQuestionId: questionFrontendId
+                    paidOnly: isPaidOnly
+                    status
+                    title
+                    titleSlug
+                    topicTags {
+                        name
+                        slug
+                    }
+                }
+            }
+        }
+        """
+
+        all_problems = []
+        skip = 0
+        limit = 100
+
+        try:
+            while True:
+                variables = {"categorySlug": "", "skip": skip, "limit": limit, "filters": {}}
+
+                response = self.http_client.post(
+                    url=self.config.leetcode_graphql_url,
+                    json={"query": query, "variables": variables},
+                    headers=self._get_headers(),
+                )
+
+                data = response.json()
+
+                # Check for GraphQL errors
+                if "errors" in data:
+                    error_msg = data["errors"][0]["message"]
+                    raise Exception(f"GraphQL error: {error_msg}")
+
+                question_list = data.get("data", {}).get("problemsetQuestionList", {})
+                questions = question_list.get("questions", [])
+                total = question_list.get("total", 0)
+
+                if not questions:
+                    break
+
+                # Apply status filter if specified
+                if status_filter:
+                    filter_lower = status_filter.lower()
+                    if filter_lower in ["ac", "solved"]:
+                        questions = [q for q in questions if q.get("status") == "ac"]
+                    elif filter_lower in ["notac", "attempted"]:
+                        questions = [q for q in questions if q.get("status") == "notac"]
+
+                # Convert to Problem entities
+                for question in questions:
+                    try:
+                        # Adapt the question data to Problem entity
+                        problem = self.adapter.adapt_problem_from_list(question)
+                        all_problems.append(problem)
+                    except Exception as e:
+                        self.logger.warning(
+                            f"Failed to adapt problem {question.get('titleSlug')}: {e}"
+                        )
+                        continue
+
+                skip += limit
+                self.logger.debug(f"Fetched {skip}/{total} problems")
+
+                # Stop if we've fetched all questions
+                if skip >= total:
+                    break
+
+            self.logger.info(f"Successfully fetched {len(all_problems)} problems with status")
+            return all_problems
+
+        except Exception as e:
+            self.logger.error(f"Failed to fetch all problems with status: {e}")
+            raise
+
     def fetch_submission(self, problem_id: str, username: str) -> Submission:
         """Fetch the last accepted submission for a problem.
 
